@@ -47,6 +47,8 @@ sub trim {
         cpan.vim > 0
             git://github.com/c9s/cpan.vim.git  # install from git repository
 
+    =libpath .
+
     =script
 
         bin/parser
@@ -56,10 +58,6 @@ sub trim {
 
 =head1 Description
 
-
-
-
-
 =head1 Constant
 
 =head2 META_FILES
@@ -223,6 +221,11 @@ sub __type {
     $self->meta->{type} =$value;
 }
 
+sub __libpath {
+    my ($self,$value) = @_;
+    $self->meta->{libpath} =$value;
+}
+
 sub __version_from {
     my ($self,$version_file) = @_;
 
